==> evms_2.3.4.orig.tar.gz: evms-2.3.4/ui/gtk/help.h <==
/*
 *
 *   (C) Copyright IBM Corp. 2001, 2003
 *
 *   This program is free software;  you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or 
 *   (at your option) any later version.
 * 
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
 *   the GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program;  if not, write to the Free Software 
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 * Module: help.h
 */

inline gchar *get_options_window_help_text(void);

inline gchar *get_create_evms_volume_help_text(void);

inline gchar *get_create_compat_volume_help_text(void);

inline gchar *get_create_feature_help_text(void);

inline gchar *get_create_region_help_text(void);

inline gchar *get_create_container_help_text(void);

inline gchar *get_create_segment_help_text(void);

inline gchar *get_delete_volume_help_text(void);

inline gchar *get_delete_object_help_text(void);

inline gchar *get_delete_region_help_text(void);

inline gchar *get_delete_container_help_text(void);

inline gchar *get_delete_segment_help_text(void);

inline gchar *get_delete_storage_object_help_text(void);

inline gchar *get_assign_segment_manager_help_text(void);

inline gchar *get_expand_volume_help_text(void);

inline gchar *get_expand_object_help_text(void);

inline gchar *get_expand_region_help_text(void);

inline gchar *get_expand_container_help_text(void);

inline gchar *get_expand_segment_help_text(void);

inline gchar *get_shrink_volume_help_text(void);

inline gchar *get_shrink_object_help_text(void);

inline gchar *get_shrink_region_help_text(void);

inline gchar *get_shrink_segment_help_text(void);

inline gchar *get_shrink_container_help_text(void);

inline gchar *get_remove_region_from_container_help_text(void);

inline gchar *get_remove_segment_from_container_help_text(void);

inline gchar *get_remove_disk_from_container_help_text(void);

inline gchar *get_remove_object_from_container_help_text(void);

inline gchar *get_modify_volume_properties_help_text(void);

inline gchar *get_modify_volume_properties_2_help_text(void);

inline gchar *get_modify_object_properties_help_text(void);

inline gchar *get_modify_region_properties_help_text(void);

inline gchar *get_modify_container_properties_help_text(void);

inline gchar *get_modify_segment_properties_help_text(void);

inline gchar *get_modify_disk_properties_help_text(void);

inline gchar *get_modify_storage_object_properties_help_text(void);

inline gchar *get_mkfs_help_text(void);

inline gchar *get_fsck_help_text(void);

inline gchar *get_defrag_help_text(void);

inline gchar *get_unmkfs_help_text(void);

inline gchar *get_acceptable_objects_help_text(void);

inline gchar *get_expansion_points_help_text(void);

inline gchar *get_shrink_points_help_text(void);

inline gchar *get_key_navigation_help_text(void);

==> evms_2.5.5.orig.tar.gz: evms-2.5.5/ui/gtk/help.h <==
/*
 *
 *   (C) Copyright IBM Corp. 2001, 2003
 *
 *   This program is free software;  you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
 *   the GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program;  if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 * Module: help.h
 */

inline gchar *get_options_window_help_text(void);

inline gchar *get_create_evms_volume_help_text(void);

inline gchar *get_create_compat_volume_help_text(void);

inline gchar *get_create_feature_help_text(void);

inline gchar *get_create_region_help_text(void);

inline gchar *get_create_container_help_text(void);

inline gchar *get_create_segment_help_text(void);

inline gchar *get_delete_volume_help_text(void);

inline gchar *get_delete_object_help_text(void);

inline gchar *get_delete_region_help_text(void);

inline gchar *get_delete_container_help_text(void);

inline gchar *get_delete_segment_help_text(void);

inline gchar *get_delete_storage_object_help_text(void);

inline gchar *get_assign_segment_manager_help_text(void);

inline gchar *get_expand_volume_help_text(void);

inline gchar *get_expand_object_help_text(void);

inline gchar *get_expand_region_help_text(void);

inline gchar *get_expand_container_help_text(void);

inline gchar *get_expand_segment_help_text(void);

inline gchar *get_shrink_volume_help_text(void);

inline gchar *get_shrink_object_help_text(void);

inline gchar *get_shrink_region_help_text(void);

inline gchar *get_shrink_segment_help_text(void);

inline gchar *get_shrink_container_help_text(void);

inline gchar *get_remove_region_from_container_help_text(void);

inline gchar *get_remove_segment_from_container_help_text(void);

inline gchar *get_remove_disk_from_container_help_text(void);

inline gchar *get_remove_object_from_container_help_text(void);

inline gchar *get_modify_volume_properties_help_text(void);

inline gchar *get_modify_volume_properties_2_help_text(void);

inline gchar *get_modify_object_properties_help_text(void);

inline gchar *get_modify_region_properties_help_text(void);

inline gchar *get_modify_container_properties_help_text(void);

inline gchar *get_modify_segment_properties_help_text(void);

inline gchar *get_modify_disk_properties_help_text(void);

inline gchar *get_modify_storage_object_properties_help_text(void);

inline gchar *get_mkfs_help_text(void);

inline gchar *get_fsck_help_text(void);

inline gchar *get_unmkfs_help_text(void);

inline gchar *get_acceptable_objects_help_text(void);

inline gchar *get_expansion_points_help_text(void);

inline gchar *get_shrink_points_help_text(void);

inline gchar *get_key_navigation_help_text(void);

inline gchar *get_activate_help_text(void);

inline gchar *get_deactivate_help_text(void);
